%
% [phi,theta,sigmaa2,muw]=fitarima(z,p,d,q,phi0,theta0)
%
% This routine fits an ARMA(p,d,q) model to the data z, using the method
% of least squares with a conditional least squares function.  
%
% Inputs:
%     z           Time series.
%     p           Number of autoregressive terms.
%     d           degree of differencing.
%     q           Number of moving average terms.
%     phi0        Initial guess for phi.
%     theta0      Initial guess for theta.
%
% Outputs:
%     phi         Optimal phi.
%     theta       Optimal theta.
%     sigmaa2     Estimated variance of the white noise.
%     muw         Mean of w (removed before fitting the ARMA process.)
%
function [phi,theta,sigmaa2,muw]=fitarima(z,p,d,q,phi0,theta0)
%
% First, difference the data d times.
%
w=z;
for i=1:d,
  w=diff(w);
end;
%
% Subtract the mean.
%
muw=mean(w);
w=w-muw*ones(size(w));
%
% Now, fit the ARMA model to w.
%
[phi,theta,sigmaa2,muw]=fitarma(w,p,q,phi0,theta0);
