%
% Load in the data.
%
load sunspotdata
%
% Plot the data.
%
figure(1);
years=1770:1865;
plot(years,sunspotdata,'ko-');
xlabel('Year');
ylabel('Sunspot Activity');
print -deps sunspot.eps
%
% Since this time series has a definite nonzero mean, we'll subtract it
% before going on.
%
mm=mean(sunspotdata)
sunspotdata=sunspotdata-mm*ones(size(sunspotdata));
%
% Plot the autocorrelations.
%
myr=zeros(30,1);
for i=1:30, myr(i)=r(sunspotdata,i); end;
figure(2);
plot(0:30,[1; myr],'ko');
xlabel('lag k');
ylabel('r_{k}');
print -deps sunspotr.eps
%
% It's apparent that no differencing is needed in this case.
%
%
% Compute and plot the partial autocorrelations.
%
phihat=pacf(myr(1:6),6)
figure(3)
plot(diag(phihat),'ko');
xlabel('lag k');
ylabel('\phi_{kk}');
print -deps sunspotpacf.eps
%
% While we're at it, plot a sample spectrum.
%
freqs=0.025:0.025:0.50;
myspec=zeros(size(freqs));
for i=1:length(freqs),
  myspec(i)=spec(sunspotdata,freqs(i));
end;
figure(4);
plot(freqs,10*log10(myspec),'k-');
xlabel('Frequency');
ylabel('PSD (db)');
print -deps sunspotspec.eps
%
% The PACF and autocorrelations suggest an ARMA(2,0) model.
%
[phi,theta,sigmaa2,muw,C]=fitarma(sunspotdata,2,0,[1.0; -0.5],[]);
disp('sigmaa2 is estimated as ');
sigmaa2
disp('phi parameters have 95\% confidence intervals ');
[phi-1.96*sqrt(diag(C)) phi phi+1.96*sqrt(diag(C))]
%
% Now, we'll forecast four years into the future.
%
% In this case, the model is very simple:
%
%  W(n)=A(n)+1.3524*W(n-1)-0.6606*W(n-2)
%
% In the prediction, we simply assume that all future A(n)'s are 0.
% Since the model has no moving average terms, we don't need the old
% A(n)'s.
%
% We will need the psi() weights to compute confidence intervals for the
% predictions.  In this case, 
% psi(B)=1+ 1.3524B + 1.1684B^2 + .6867B^3 + .1569B^4 + ... 
%
w=sunspotdata;
n=length(w);
for i=n+1:n+4,
  w(i)=1.3524*w(i-1)-0.6606*w(i-2);
end;
%
% Compute the variances for the predictions.
%
v(1)=sigmaa2*1;
v(2)=sigmaa2*(1+1.3524^2);
v(3)=sigmaa2*(1+1.3524^2+1.1684^2);
v(4)=sigmaa2*(1+1.3524^2+1.1684^2+0.6867^2);
%
% Now, print out the confidence intervals.
%
disp('Predictions for 1866-1869, with confidence intervals');
[mm+w(n+1)-1.96*sqrt(v(1)) mm+w(n+1) mm+w(n+1)+1.96*sqrt(v(1));
 mm+w(n+2)-1.96*sqrt(v(2)) mm+w(n+2) mm+w(n+2)+1.96*sqrt(v(2));
 mm+w(n+3)-1.96*sqrt(v(3)) mm+w(n+3) mm+w(n+3)+1.96*sqrt(v(2));
 mm+w(n+4)-1.96*sqrt(v(4)) mm+w(n+4) mm+w(n+4)+1.96*sqrt(v(3))]







